#ifndef NT2_INCLUDE_FUNCTIONS_ISSORTED_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ISSORTED_HPP_INCLUDED

#include <nt2/predicates/include/functions/issorted.hpp>

#endif
